# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['ModelArgs', 'Model']

@pulumi.input_type
class ModelArgs:
    def __init__(__self__, *,
                 group_id: pulumi.Input[str],
                 model_name: pulumi.Input[str],
                 schema: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Model resource.
        :param pulumi.Input[str] group_id: The group of the model belongs to.
        :param pulumi.Input[str] model_name: The name of the model.
        :param pulumi.Input[str] schema: The schema of the model.
        :param pulumi.Input[str] description: The description of the model.
        """
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "model_name", model_name)
        pulumi.set(__self__, "schema", schema)
        if description is not None:
            pulumi.set(__self__, "description", description)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[str]:
        """
        The group of the model belongs to.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="modelName")
    def model_name(self) -> pulumi.Input[str]:
        """
        The name of the model.
        """
        return pulumi.get(self, "model_name")

    @model_name.setter
    def model_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "model_name", value)

    @property
    @pulumi.getter
    def schema(self) -> pulumi.Input[str]:
        """
        The schema of the model.
        """
        return pulumi.get(self, "schema")

    @schema.setter
    def schema(self, value: pulumi.Input[str]):
        pulumi.set(self, "schema", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the model.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)


@pulumi.input_type
class _ModelState:
    def __init__(__self__, *,
                 description: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 model_name: Optional[pulumi.Input[str]] = None,
                 schema: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Model resources.
        :param pulumi.Input[str] description: The description of the model.
        :param pulumi.Input[str] group_id: The group of the model belongs to.
        :param pulumi.Input[str] model_name: The name of the model.
        :param pulumi.Input[str] schema: The schema of the model.
        """
        if description is not None:
            pulumi.set(__self__, "description", description)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if model_name is not None:
            pulumi.set(__self__, "model_name", model_name)
        if schema is not None:
            pulumi.set(__self__, "schema", schema)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the model.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[str]]:
        """
        The group of the model belongs to.
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="modelName")
    def model_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the model.
        """
        return pulumi.get(self, "model_name")

    @model_name.setter
    def model_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "model_name", value)

    @property
    @pulumi.getter
    def schema(self) -> Optional[pulumi.Input[str]]:
        """
        The schema of the model.
        """
        return pulumi.get(self, "schema")

    @schema.setter
    def schema(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "schema", value)


class Model(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 model_name: Optional[pulumi.Input[str]] = None,
                 schema: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Api Gateway Model resource.

        For information about Api Gateway Model and how to use it, see [What is Model](https://www.alibabacloud.com/help/en/api-gateway/latest/api-cloudapi-2016-07-14-createmodel).

        > **NOTE:** Available since v1.187.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.apigateway.Group("default",
            name="example_value",
            description="example_value")
        default_model = alicloud.apigateway.Model("default",
            group_id=default.id,
            model_name="example_value",
            schema="{\\"type\\":\\"object\\",\\"properties\\":{\\"id\\":{\\"format\\":\\"int64\\",\\"maximum\\":100,\\"exclusiveMaximum\\":true,\\"type\\":\\"integer\\"},\\"name\\":{\\"maxLength\\":10,\\"type\\":\\"string\\"}}}",
            description="example_value")
        ```

        ## Import

        Api Gateway Model can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:apigateway/model:Model example <group_id>:<model_name>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the model.
        :param pulumi.Input[str] group_id: The group of the model belongs to.
        :param pulumi.Input[str] model_name: The name of the model.
        :param pulumi.Input[str] schema: The schema of the model.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: ModelArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Api Gateway Model resource.

        For information about Api Gateway Model and how to use it, see [What is Model](https://www.alibabacloud.com/help/en/api-gateway/latest/api-cloudapi-2016-07-14-createmodel).

        > **NOTE:** Available since v1.187.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        default = alicloud.apigateway.Group("default",
            name="example_value",
            description="example_value")
        default_model = alicloud.apigateway.Model("default",
            group_id=default.id,
            model_name="example_value",
            schema="{\\"type\\":\\"object\\",\\"properties\\":{\\"id\\":{\\"format\\":\\"int64\\",\\"maximum\\":100,\\"exclusiveMaximum\\":true,\\"type\\":\\"integer\\"},\\"name\\":{\\"maxLength\\":10,\\"type\\":\\"string\\"}}}",
            description="example_value")
        ```

        ## Import

        Api Gateway Model can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:apigateway/model:Model example <group_id>:<model_name>
        ```

        :param str resource_name: The name of the resource.
        :param ModelArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(ModelArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 model_name: Optional[pulumi.Input[str]] = None,
                 schema: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = ModelArgs.__new__(ModelArgs)

            __props__.__dict__["description"] = description
            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            if model_name is None and not opts.urn:
                raise TypeError("Missing required property 'model_name'")
            __props__.__dict__["model_name"] = model_name
            if schema is None and not opts.urn:
                raise TypeError("Missing required property 'schema'")
            __props__.__dict__["schema"] = schema
        super(Model, __self__).__init__(
            'alicloud:apigateway/model:Model',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            description: Optional[pulumi.Input[str]] = None,
            group_id: Optional[pulumi.Input[str]] = None,
            model_name: Optional[pulumi.Input[str]] = None,
            schema: Optional[pulumi.Input[str]] = None) -> 'Model':
        """
        Get an existing Model resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] description: The description of the model.
        :param pulumi.Input[str] group_id: The group of the model belongs to.
        :param pulumi.Input[str] model_name: The name of the model.
        :param pulumi.Input[str] schema: The schema of the model.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _ModelState.__new__(_ModelState)

        __props__.__dict__["description"] = description
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["model_name"] = model_name
        __props__.__dict__["schema"] = schema
        return Model(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the model.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[str]:
        """
        The group of the model belongs to.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="modelName")
    def model_name(self) -> pulumi.Output[str]:
        """
        The name of the model.
        """
        return pulumi.get(self, "model_name")

    @property
    @pulumi.getter
    def schema(self) -> pulumi.Output[str]:
        """
        The schema of the model.
        """
        return pulumi.get(self, "schema")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 https_policy: pulumi.Input[str],
                 instance_name: pulumi.Input[str],
                 instance_spec: pulumi.Input[str],
                 payment_type: pulumi.Input[str],
                 delete_vpc_ip_block: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 egress_ipv6_enable: Optional[pulumi.Input[bool]] = None,
                 instance_cidr: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 ipv6_enabled: Optional[pulumi.Input[bool]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 to_connect_vpc_ip_block: Optional[pulumi.Input['InstanceToConnectVpcIpBlockArgs']] = None,
                 user_vpc_id: Optional[pulumi.Input[str]] = None,
                 vpc_slb_intranet_enable: Optional[pulumi.Input[bool]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None,
                 zone_vswitch_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceZoneVswitchSecurityGroupArgs']]]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input[str] https_policy: Https policy.
        :param pulumi.Input[str] instance_name: Instance name.
        :param pulumi.Input[str] instance_spec: Instance type.
        :param pulumi.Input[str] payment_type: The payment type of the resource.
        :param pulumi.Input[str] delete_vpc_ip_block: Indicates whether to delete the IP block that the VPC can access, conflict with `to_connect_vpc_ip_block`.
        :param pulumi.Input[int] duration: The time of the instance package. Valid values:
               - PricingCycle is **Month**, indicating monthly payment. The value range is **1** to **9**.
               - PricingCycle is **Year**, indicating annual payment. The value range is **1** to **3**.
               
               When the value of> ChargeType is **PrePaid**, this parameter is available and must be passed in.
        :param pulumi.Input[bool] egress_ipv6_enable: Specifies whether IPv6 egress capability is enabled.
        :param pulumi.Input[str] instance_cidr: The CIDR block for the instance deployment. Valid values are:
               - `192.168.0.0/16`.
               - `172.16.0.0/12`.
        :param pulumi.Input[str] instance_type: The type of the instance. Valid values are:
        :param pulumi.Input[bool] ipv6_enabled: Specifies whether IPv6 ingress capability is enabled.
        :param pulumi.Input[str] pricing_cycle: The subscription instance is of the subscription year or month type. This parameter is required when the Payment type is PrePaid. The value range is as follows:
        :param pulumi.Input['InstanceToConnectVpcIpBlockArgs'] to_connect_vpc_ip_block: The additional IP block that the VPC integration instance can access, conflict with `delete_vpc_ip_block`. See `to_connect_vpc_ip_block` below.
        :param pulumi.Input[str] user_vpc_id: User's VpcID.
        :param pulumi.Input[bool] vpc_slb_intranet_enable: Whether the slb of the Vpc supports.
        :param pulumi.Input[str] zone_id: The zone where the instance is deployed.
        :param pulumi.Input[Sequence[pulumi.Input['InstanceZoneVswitchSecurityGroupArgs']]] zone_vswitch_security_groups: Network configuration details for Vpc integration instance which includes the availability zone, VSwitch, and security group information. See `zone_vswitch_security_group` below.
        """
        pulumi.set(__self__, "https_policy", https_policy)
        pulumi.set(__self__, "instance_name", instance_name)
        pulumi.set(__self__, "instance_spec", instance_spec)
        pulumi.set(__self__, "payment_type", payment_type)
        if delete_vpc_ip_block is not None:
            pulumi.set(__self__, "delete_vpc_ip_block", delete_vpc_ip_block)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if egress_ipv6_enable is not None:
            pulumi.set(__self__, "egress_ipv6_enable", egress_ipv6_enable)
        if instance_cidr is not None:
            pulumi.set(__self__, "instance_cidr", instance_cidr)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if ipv6_enabled is not None:
            pulumi.set(__self__, "ipv6_enabled", ipv6_enabled)
        if pricing_cycle is not None:
            pulumi.set(__self__, "pricing_cycle", pricing_cycle)
        if to_connect_vpc_ip_block is not None:
            pulumi.set(__self__, "to_connect_vpc_ip_block", to_connect_vpc_ip_block)
        if user_vpc_id is not None:
            pulumi.set(__self__, "user_vpc_id", user_vpc_id)
        if vpc_slb_intranet_enable is not None:
            pulumi.set(__self__, "vpc_slb_intranet_enable", vpc_slb_intranet_enable)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)
        if zone_vswitch_security_groups is not None:
            pulumi.set(__self__, "zone_vswitch_security_groups", zone_vswitch_security_groups)

    @property
    @pulumi.getter(name="httpsPolicy")
    def https_policy(self) -> pulumi.Input[str]:
        """
        Https policy.
        """
        return pulumi.get(self, "https_policy")

    @https_policy.setter
    def https_policy(self, value: pulumi.Input[str]):
        pulumi.set(self, "https_policy", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Input[str]:
        """
        Instance name.
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceSpec")
    def instance_spec(self) -> pulumi.Input[str]:
        """
        Instance type.
        """
        return pulumi.get(self, "instance_spec")

    @instance_spec.setter
    def instance_spec(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_spec", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Input[str]:
        """
        The payment type of the resource.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="deleteVpcIpBlock")
    def delete_vpc_ip_block(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates whether to delete the IP block that the VPC can access, conflict with `to_connect_vpc_ip_block`.
        """
        return pulumi.get(self, "delete_vpc_ip_block")

    @delete_vpc_ip_block.setter
    def delete_vpc_ip_block(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "delete_vpc_ip_block", value)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[int]]:
        """
        The time of the instance package. Valid values:
        - PricingCycle is **Month**, indicating monthly payment. The value range is **1** to **9**.
        - PricingCycle is **Year**, indicating annual payment. The value range is **1** to **3**.

        When the value of> ChargeType is **PrePaid**, this parameter is available and must be passed in.
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="egressIpv6Enable")
    def egress_ipv6_enable(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether IPv6 egress capability is enabled.
        """
        return pulumi.get(self, "egress_ipv6_enable")

    @egress_ipv6_enable.setter
    def egress_ipv6_enable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "egress_ipv6_enable", value)

    @property
    @pulumi.getter(name="instanceCidr")
    def instance_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The CIDR block for the instance deployment. Valid values are:
        - `192.168.0.0/16`.
        - `172.16.0.0/12`.
        """
        return pulumi.get(self, "instance_cidr")

    @instance_cidr.setter
    def instance_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_cidr", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the instance. Valid values are:
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="ipv6Enabled")
    def ipv6_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether IPv6 ingress capability is enabled.
        """
        return pulumi.get(self, "ipv6_enabled")

    @ipv6_enabled.setter
    def ipv6_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ipv6_enabled", value)

    @property
    @pulumi.getter(name="pricingCycle")
    def pricing_cycle(self) -> Optional[pulumi.Input[str]]:
        """
        The subscription instance is of the subscription year or month type. This parameter is required when the Payment type is PrePaid. The value range is as follows:
        """
        return pulumi.get(self, "pricing_cycle")

    @pricing_cycle.setter
    def pricing_cycle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pricing_cycle", value)

    @property
    @pulumi.getter(name="toConnectVpcIpBlock")
    def to_connect_vpc_ip_block(self) -> Optional[pulumi.Input['InstanceToConnectVpcIpBlockArgs']]:
        """
        The additional IP block that the VPC integration instance can access, conflict with `delete_vpc_ip_block`. See `to_connect_vpc_ip_block` below.
        """
        return pulumi.get(self, "to_connect_vpc_ip_block")

    @to_connect_vpc_ip_block.setter
    def to_connect_vpc_ip_block(self, value: Optional[pulumi.Input['InstanceToConnectVpcIpBlockArgs']]):
        pulumi.set(self, "to_connect_vpc_ip_block", value)

    @property
    @pulumi.getter(name="userVpcId")
    def user_vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        User's VpcID.
        """
        return pulumi.get(self, "user_vpc_id")

    @user_vpc_id.setter
    def user_vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_vpc_id", value)

    @property
    @pulumi.getter(name="vpcSlbIntranetEnable")
    def vpc_slb_intranet_enable(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the slb of the Vpc supports.
        """
        return pulumi.get(self, "vpc_slb_intranet_enable")

    @vpc_slb_intranet_enable.setter
    def vpc_slb_intranet_enable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "vpc_slb_intranet_enable", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[str]]:
        """
        The zone where the instance is deployed.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter(name="zoneVswitchSecurityGroups")
    def zone_vswitch_security_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceZoneVswitchSecurityGroupArgs']]]]:
        """
        Network configuration details for Vpc integration instance which includes the availability zone, VSwitch, and security group information. See `zone_vswitch_security_group` below.
        """
        return pulumi.get(self, "zone_vswitch_security_groups")

    @zone_vswitch_security_groups.setter
    def zone_vswitch_security_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceZoneVswitchSecurityGroupArgs']]]]):
        pulumi.set(self, "zone_vswitch_security_groups", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 connect_cidr_blocks: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 delete_vpc_ip_block: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 egress_ipv6_enable: Optional[pulumi.Input[bool]] = None,
                 https_policy: Optional[pulumi.Input[str]] = None,
                 instance_cidr: Optional[pulumi.Input[str]] = None,
                 instance_name: Optional[pulumi.Input[str]] = None,
                 instance_spec: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 ipv6_enabled: Optional[pulumi.Input[bool]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 support_ipv6: Optional[pulumi.Input[bool]] = None,
                 to_connect_vpc_ip_block: Optional[pulumi.Input['InstanceToConnectVpcIpBlockArgs']] = None,
                 user_vpc_id: Optional[pulumi.Input[str]] = None,
                 vpc_slb_intranet_enable: Optional[pulumi.Input[bool]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None,
                 zone_vswitch_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceZoneVswitchSecurityGroupArgs']]]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[str] connect_cidr_blocks: (Available since v1.228.0) The CIDR blocks that can be accessed by the Vpc integration instance.
        :param pulumi.Input[str] create_time: Creation time.
        :param pulumi.Input[str] delete_vpc_ip_block: Indicates whether to delete the IP block that the VPC can access, conflict with `to_connect_vpc_ip_block`.
        :param pulumi.Input[int] duration: The time of the instance package. Valid values:
               - PricingCycle is **Month**, indicating monthly payment. The value range is **1** to **9**.
               - PricingCycle is **Year**, indicating annual payment. The value range is **1** to **3**.
               
               When the value of> ChargeType is **PrePaid**, this parameter is available and must be passed in.
        :param pulumi.Input[bool] egress_ipv6_enable: Specifies whether IPv6 egress capability is enabled.
        :param pulumi.Input[str] https_policy: Https policy.
        :param pulumi.Input[str] instance_cidr: The CIDR block for the instance deployment. Valid values are:
               - `192.168.0.0/16`.
               - `172.16.0.0/12`.
        :param pulumi.Input[str] instance_name: Instance name.
        :param pulumi.Input[str] instance_spec: Instance type.
        :param pulumi.Input[str] instance_type: The type of the instance. Valid values are:
        :param pulumi.Input[bool] ipv6_enabled: Specifies whether IPv6 ingress capability is enabled.
        :param pulumi.Input[str] payment_type: The payment type of the resource.
        :param pulumi.Input[str] pricing_cycle: The subscription instance is of the subscription year or month type. This parameter is required when the Payment type is PrePaid. The value range is as follows:
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[bool] support_ipv6: Does ipv6 support.
        :param pulumi.Input['InstanceToConnectVpcIpBlockArgs'] to_connect_vpc_ip_block: The additional IP block that the VPC integration instance can access, conflict with `delete_vpc_ip_block`. See `to_connect_vpc_ip_block` below.
        :param pulumi.Input[str] user_vpc_id: User's VpcID.
        :param pulumi.Input[bool] vpc_slb_intranet_enable: Whether the slb of the Vpc supports.
        :param pulumi.Input[str] zone_id: The zone where the instance is deployed.
        :param pulumi.Input[Sequence[pulumi.Input['InstanceZoneVswitchSecurityGroupArgs']]] zone_vswitch_security_groups: Network configuration details for Vpc integration instance which includes the availability zone, VSwitch, and security group information. See `zone_vswitch_security_group` below.
        """
        if connect_cidr_blocks is not None:
            pulumi.set(__self__, "connect_cidr_blocks", connect_cidr_blocks)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if delete_vpc_ip_block is not None:
            pulumi.set(__self__, "delete_vpc_ip_block", delete_vpc_ip_block)
        if duration is not None:
            pulumi.set(__self__, "duration", duration)
        if egress_ipv6_enable is not None:
            pulumi.set(__self__, "egress_ipv6_enable", egress_ipv6_enable)
        if https_policy is not None:
            pulumi.set(__self__, "https_policy", https_policy)
        if instance_cidr is not None:
            pulumi.set(__self__, "instance_cidr", instance_cidr)
        if instance_name is not None:
            pulumi.set(__self__, "instance_name", instance_name)
        if instance_spec is not None:
            pulumi.set(__self__, "instance_spec", instance_spec)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if ipv6_enabled is not None:
            pulumi.set(__self__, "ipv6_enabled", ipv6_enabled)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if pricing_cycle is not None:
            pulumi.set(__self__, "pricing_cycle", pricing_cycle)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if support_ipv6 is not None:
            pulumi.set(__self__, "support_ipv6", support_ipv6)
        if to_connect_vpc_ip_block is not None:
            pulumi.set(__self__, "to_connect_vpc_ip_block", to_connect_vpc_ip_block)
        if user_vpc_id is not None:
            pulumi.set(__self__, "user_vpc_id", user_vpc_id)
        if vpc_slb_intranet_enable is not None:
            pulumi.set(__self__, "vpc_slb_intranet_enable", vpc_slb_intranet_enable)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)
        if zone_vswitch_security_groups is not None:
            pulumi.set(__self__, "zone_vswitch_security_groups", zone_vswitch_security_groups)

    @property
    @pulumi.getter(name="connectCidrBlocks")
    def connect_cidr_blocks(self) -> Optional[pulumi.Input[str]]:
        """
        (Available since v1.228.0) The CIDR blocks that can be accessed by the Vpc integration instance.
        """
        return pulumi.get(self, "connect_cidr_blocks")

    @connect_cidr_blocks.setter
    def connect_cidr_blocks(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connect_cidr_blocks", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="deleteVpcIpBlock")
    def delete_vpc_ip_block(self) -> Optional[pulumi.Input[str]]:
        """
        Indicates whether to delete the IP block that the VPC can access, conflict with `to_connect_vpc_ip_block`.
        """
        return pulumi.get(self, "delete_vpc_ip_block")

    @delete_vpc_ip_block.setter
    def delete_vpc_ip_block(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "delete_vpc_ip_block", value)

    @property
    @pulumi.getter
    def duration(self) -> Optional[pulumi.Input[int]]:
        """
        The time of the instance package. Valid values:
        - PricingCycle is **Month**, indicating monthly payment. The value range is **1** to **9**.
        - PricingCycle is **Year**, indicating annual payment. The value range is **1** to **3**.

        When the value of> ChargeType is **PrePaid**, this parameter is available and must be passed in.
        """
        return pulumi.get(self, "duration")

    @duration.setter
    def duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "duration", value)

    @property
    @pulumi.getter(name="egressIpv6Enable")
    def egress_ipv6_enable(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether IPv6 egress capability is enabled.
        """
        return pulumi.get(self, "egress_ipv6_enable")

    @egress_ipv6_enable.setter
    def egress_ipv6_enable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "egress_ipv6_enable", value)

    @property
    @pulumi.getter(name="httpsPolicy")
    def https_policy(self) -> Optional[pulumi.Input[str]]:
        """
        Https policy.
        """
        return pulumi.get(self, "https_policy")

    @https_policy.setter
    def https_policy(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "https_policy", value)

    @property
    @pulumi.getter(name="instanceCidr")
    def instance_cidr(self) -> Optional[pulumi.Input[str]]:
        """
        The CIDR block for the instance deployment. Valid values are:
        - `192.168.0.0/16`.
        - `172.16.0.0/12`.
        """
        return pulumi.get(self, "instance_cidr")

    @instance_cidr.setter
    def instance_cidr(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_cidr", value)

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> Optional[pulumi.Input[str]]:
        """
        Instance name.
        """
        return pulumi.get(self, "instance_name")

    @instance_name.setter
    def instance_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_name", value)

    @property
    @pulumi.getter(name="instanceSpec")
    def instance_spec(self) -> Optional[pulumi.Input[str]]:
        """
        Instance type.
        """
        return pulumi.get(self, "instance_spec")

    @instance_spec.setter
    def instance_spec(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_spec", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the instance. Valid values are:
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="ipv6Enabled")
    def ipv6_enabled(self) -> Optional[pulumi.Input[bool]]:
        """
        Specifies whether IPv6 ingress capability is enabled.
        """
        return pulumi.get(self, "ipv6_enabled")

    @ipv6_enabled.setter
    def ipv6_enabled(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "ipv6_enabled", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The payment type of the resource.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="pricingCycle")
    def pricing_cycle(self) -> Optional[pulumi.Input[str]]:
        """
        The subscription instance is of the subscription year or month type. This parameter is required when the Payment type is PrePaid. The value range is as follows:
        """
        return pulumi.get(self, "pricing_cycle")

    @pricing_cycle.setter
    def pricing_cycle(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pricing_cycle", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="supportIpv6")
    def support_ipv6(self) -> Optional[pulumi.Input[bool]]:
        """
        Does ipv6 support.
        """
        return pulumi.get(self, "support_ipv6")

    @support_ipv6.setter
    def support_ipv6(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "support_ipv6", value)

    @property
    @pulumi.getter(name="toConnectVpcIpBlock")
    def to_connect_vpc_ip_block(self) -> Optional[pulumi.Input['InstanceToConnectVpcIpBlockArgs']]:
        """
        The additional IP block that the VPC integration instance can access, conflict with `delete_vpc_ip_block`. See `to_connect_vpc_ip_block` below.
        """
        return pulumi.get(self, "to_connect_vpc_ip_block")

    @to_connect_vpc_ip_block.setter
    def to_connect_vpc_ip_block(self, value: Optional[pulumi.Input['InstanceToConnectVpcIpBlockArgs']]):
        pulumi.set(self, "to_connect_vpc_ip_block", value)

    @property
    @pulumi.getter(name="userVpcId")
    def user_vpc_id(self) -> Optional[pulumi.Input[str]]:
        """
        User's VpcID.
        """
        return pulumi.get(self, "user_vpc_id")

    @user_vpc_id.setter
    def user_vpc_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_vpc_id", value)

    @property
    @pulumi.getter(name="vpcSlbIntranetEnable")
    def vpc_slb_intranet_enable(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether the slb of the Vpc supports.
        """
        return pulumi.get(self, "vpc_slb_intranet_enable")

    @vpc_slb_intranet_enable.setter
    def vpc_slb_intranet_enable(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "vpc_slb_intranet_enable", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[str]]:
        """
        The zone where the instance is deployed.
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter(name="zoneVswitchSecurityGroups")
    def zone_vswitch_security_groups(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['InstanceZoneVswitchSecurityGroupArgs']]]]:
        """
        Network configuration details for Vpc integration instance which includes the availability zone, VSwitch, and security group information. See `zone_vswitch_security_group` below.
        """
        return pulumi.get(self, "zone_vswitch_security_groups")

    @zone_vswitch_security_groups.setter
    def zone_vswitch_security_groups(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['InstanceZoneVswitchSecurityGroupArgs']]]]):
        pulumi.set(self, "zone_vswitch_security_groups", value)


class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delete_vpc_ip_block: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 egress_ipv6_enable: Optional[pulumi.Input[bool]] = None,
                 https_policy: Optional[pulumi.Input[str]] = None,
                 instance_cidr: Optional[pulumi.Input[str]] = None,
                 instance_name: Optional[pulumi.Input[str]] = None,
                 instance_spec: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 ipv6_enabled: Optional[pulumi.Input[bool]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 to_connect_vpc_ip_block: Optional[pulumi.Input[Union['InstanceToConnectVpcIpBlockArgs', 'InstanceToConnectVpcIpBlockArgsDict']]] = None,
                 user_vpc_id: Optional[pulumi.Input[str]] = None,
                 vpc_slb_intranet_enable: Optional[pulumi.Input[bool]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None,
                 zone_vswitch_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceZoneVswitchSecurityGroupArgs', 'InstanceZoneVswitchSecurityGroupArgsDict']]]]] = None,
                 __props__=None):
        """
        Provides a Api Gateway Instance resource.

        For information about Api Gateway Instance and how to use it, see [What is Instance](https://www.alibabacloud.com/help/en/api-gateway/product-overview/dedicated-instances).

        > **NOTE:** Available since v1.218.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.apigateway.Instance("default",
            instance_name=name,
            instance_spec="api.s1.small",
            https_policy="HTTPS2_TLS1_0",
            zone_id="cn-hangzhou-MAZ6",
            payment_type="PayAsYouGo",
            instance_type="normal")
        ```

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        vpc = alicloud.vpc.Network("vpc",
            cidr_block="172.16.0.0/12",
            vpc_name=name)
        vswitch1 = alicloud.vpc.Switch("vswitch_1",
            vpc_id=vpc.id,
            cidr_block="172.16.0.0/16",
            zone_id="cn-hangzhou-j",
            vswitch_name=f"{name}_1")
        vswitch2 = alicloud.vpc.Switch("vswitch_2",
            vpc_id=vpc.id,
            cidr_block="172.17.0.0/16",
            zone_id="cn-hangzhou-k",
            vswitch_name=f"{name}_2")
        security_group = alicloud.ecs.SecurityGroup("security_group",
            vpc_id=vpc.id,
            name=name)
        vpc_integration_instance = alicloud.apigateway.Instance("vpc_integration_instance",
            instance_name=name,
            https_policy="HTTPS2_TLS1_0",
            instance_spec="api.s1.small",
            instance_type="vpc_connect",
            payment_type="PayAsYouGo",
            user_vpc_id=vpc.id,
            instance_cidr="192.168.0.0/16",
            zone_vswitch_security_groups=[
                {
                    "zone_id": vswitch1.zone_id,
                    "vswitch_id": vswitch1.id,
                    "cidr_block": vswitch1.cidr_block,
                    "security_group": security_group.id,
                },
                {
                    "zone_id": vswitch2.zone_id,
                    "vswitch_id": vswitch2.id,
                    "cidr_block": vswitch2.cidr_block,
                    "security_group": security_group.id,
                },
            ])
        ```

        ## Import

        Api Gateway Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:apigateway/instance:Instance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] delete_vpc_ip_block: Indicates whether to delete the IP block that the VPC can access, conflict with `to_connect_vpc_ip_block`.
        :param pulumi.Input[int] duration: The time of the instance package. Valid values:
               - PricingCycle is **Month**, indicating monthly payment. The value range is **1** to **9**.
               - PricingCycle is **Year**, indicating annual payment. The value range is **1** to **3**.
               
               When the value of> ChargeType is **PrePaid**, this parameter is available and must be passed in.
        :param pulumi.Input[bool] egress_ipv6_enable: Specifies whether IPv6 egress capability is enabled.
        :param pulumi.Input[str] https_policy: Https policy.
        :param pulumi.Input[str] instance_cidr: The CIDR block for the instance deployment. Valid values are:
               - `192.168.0.0/16`.
               - `172.16.0.0/12`.
        :param pulumi.Input[str] instance_name: Instance name.
        :param pulumi.Input[str] instance_spec: Instance type.
        :param pulumi.Input[str] instance_type: The type of the instance. Valid values are:
        :param pulumi.Input[bool] ipv6_enabled: Specifies whether IPv6 ingress capability is enabled.
        :param pulumi.Input[str] payment_type: The payment type of the resource.
        :param pulumi.Input[str] pricing_cycle: The subscription instance is of the subscription year or month type. This parameter is required when the Payment type is PrePaid. The value range is as follows:
        :param pulumi.Input[Union['InstanceToConnectVpcIpBlockArgs', 'InstanceToConnectVpcIpBlockArgsDict']] to_connect_vpc_ip_block: The additional IP block that the VPC integration instance can access, conflict with `delete_vpc_ip_block`. See `to_connect_vpc_ip_block` below.
        :param pulumi.Input[str] user_vpc_id: User's VpcID.
        :param pulumi.Input[bool] vpc_slb_intranet_enable: Whether the slb of the Vpc supports.
        :param pulumi.Input[str] zone_id: The zone where the instance is deployed.
        :param pulumi.Input[Sequence[pulumi.Input[Union['InstanceZoneVswitchSecurityGroupArgs', 'InstanceZoneVswitchSecurityGroupArgsDict']]]] zone_vswitch_security_groups: Network configuration details for Vpc integration instance which includes the availability zone, VSwitch, and security group information. See `zone_vswitch_security_group` below.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Api Gateway Instance resource.

        For information about Api Gateway Instance and how to use it, see [What is Instance](https://www.alibabacloud.com/help/en/api-gateway/product-overview/dedicated-instances).

        > **NOTE:** Available since v1.218.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.apigateway.Instance("default",
            instance_name=name,
            instance_spec="api.s1.small",
            https_policy="HTTPS2_TLS1_0",
            zone_id="cn-hangzhou-MAZ6",
            payment_type="PayAsYouGo",
            instance_type="normal")
        ```

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        vpc = alicloud.vpc.Network("vpc",
            cidr_block="172.16.0.0/12",
            vpc_name=name)
        vswitch1 = alicloud.vpc.Switch("vswitch_1",
            vpc_id=vpc.id,
            cidr_block="172.16.0.0/16",
            zone_id="cn-hangzhou-j",
            vswitch_name=f"{name}_1")
        vswitch2 = alicloud.vpc.Switch("vswitch_2",
            vpc_id=vpc.id,
            cidr_block="172.17.0.0/16",
            zone_id="cn-hangzhou-k",
            vswitch_name=f"{name}_2")
        security_group = alicloud.ecs.SecurityGroup("security_group",
            vpc_id=vpc.id,
            name=name)
        vpc_integration_instance = alicloud.apigateway.Instance("vpc_integration_instance",
            instance_name=name,
            https_policy="HTTPS2_TLS1_0",
            instance_spec="api.s1.small",
            instance_type="vpc_connect",
            payment_type="PayAsYouGo",
            user_vpc_id=vpc.id,
            instance_cidr="192.168.0.0/16",
            zone_vswitch_security_groups=[
                {
                    "zone_id": vswitch1.zone_id,
                    "vswitch_id": vswitch1.id,
                    "cidr_block": vswitch1.cidr_block,
                    "security_group": security_group.id,
                },
                {
                    "zone_id": vswitch2.zone_id,
                    "vswitch_id": vswitch2.id,
                    "cidr_block": vswitch2.cidr_block,
                    "security_group": security_group.id,
                },
            ])
        ```

        ## Import

        Api Gateway Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:apigateway/instance:Instance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 delete_vpc_ip_block: Optional[pulumi.Input[str]] = None,
                 duration: Optional[pulumi.Input[int]] = None,
                 egress_ipv6_enable: Optional[pulumi.Input[bool]] = None,
                 https_policy: Optional[pulumi.Input[str]] = None,
                 instance_cidr: Optional[pulumi.Input[str]] = None,
                 instance_name: Optional[pulumi.Input[str]] = None,
                 instance_spec: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 ipv6_enabled: Optional[pulumi.Input[bool]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 pricing_cycle: Optional[pulumi.Input[str]] = None,
                 to_connect_vpc_ip_block: Optional[pulumi.Input[Union['InstanceToConnectVpcIpBlockArgs', 'InstanceToConnectVpcIpBlockArgsDict']]] = None,
                 user_vpc_id: Optional[pulumi.Input[str]] = None,
                 vpc_slb_intranet_enable: Optional[pulumi.Input[bool]] = None,
                 zone_id: Optional[pulumi.Input[str]] = None,
                 zone_vswitch_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceZoneVswitchSecurityGroupArgs', 'InstanceZoneVswitchSecurityGroupArgsDict']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            __props__.__dict__["delete_vpc_ip_block"] = delete_vpc_ip_block
            __props__.__dict__["duration"] = duration
            __props__.__dict__["egress_ipv6_enable"] = egress_ipv6_enable
            if https_policy is None and not opts.urn:
                raise TypeError("Missing required property 'https_policy'")
            __props__.__dict__["https_policy"] = https_policy
            __props__.__dict__["instance_cidr"] = instance_cidr
            if instance_name is None and not opts.urn:
                raise TypeError("Missing required property 'instance_name'")
            __props__.__dict__["instance_name"] = instance_name
            if instance_spec is None and not opts.urn:
                raise TypeError("Missing required property 'instance_spec'")
            __props__.__dict__["instance_spec"] = instance_spec
            __props__.__dict__["instance_type"] = instance_type
            __props__.__dict__["ipv6_enabled"] = ipv6_enabled
            if payment_type is None and not opts.urn:
                raise TypeError("Missing required property 'payment_type'")
            __props__.__dict__["payment_type"] = payment_type
            __props__.__dict__["pricing_cycle"] = pricing_cycle
            __props__.__dict__["to_connect_vpc_ip_block"] = to_connect_vpc_ip_block
            __props__.__dict__["user_vpc_id"] = user_vpc_id
            __props__.__dict__["vpc_slb_intranet_enable"] = vpc_slb_intranet_enable
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["zone_vswitch_security_groups"] = zone_vswitch_security_groups
            __props__.__dict__["connect_cidr_blocks"] = None
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["support_ipv6"] = None
        super(Instance, __self__).__init__(
            'alicloud:apigateway/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            connect_cidr_blocks: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            delete_vpc_ip_block: Optional[pulumi.Input[str]] = None,
            duration: Optional[pulumi.Input[int]] = None,
            egress_ipv6_enable: Optional[pulumi.Input[bool]] = None,
            https_policy: Optional[pulumi.Input[str]] = None,
            instance_cidr: Optional[pulumi.Input[str]] = None,
            instance_name: Optional[pulumi.Input[str]] = None,
            instance_spec: Optional[pulumi.Input[str]] = None,
            instance_type: Optional[pulumi.Input[str]] = None,
            ipv6_enabled: Optional[pulumi.Input[bool]] = None,
            payment_type: Optional[pulumi.Input[str]] = None,
            pricing_cycle: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            support_ipv6: Optional[pulumi.Input[bool]] = None,
            to_connect_vpc_ip_block: Optional[pulumi.Input[Union['InstanceToConnectVpcIpBlockArgs', 'InstanceToConnectVpcIpBlockArgsDict']]] = None,
            user_vpc_id: Optional[pulumi.Input[str]] = None,
            vpc_slb_intranet_enable: Optional[pulumi.Input[bool]] = None,
            zone_id: Optional[pulumi.Input[str]] = None,
            zone_vswitch_security_groups: Optional[pulumi.Input[Sequence[pulumi.Input[Union['InstanceZoneVswitchSecurityGroupArgs', 'InstanceZoneVswitchSecurityGroupArgsDict']]]]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] connect_cidr_blocks: (Available since v1.228.0) The CIDR blocks that can be accessed by the Vpc integration instance.
        :param pulumi.Input[str] create_time: Creation time.
        :param pulumi.Input[str] delete_vpc_ip_block: Indicates whether to delete the IP block that the VPC can access, conflict with `to_connect_vpc_ip_block`.
        :param pulumi.Input[int] duration: The time of the instance package. Valid values:
               - PricingCycle is **Month**, indicating monthly payment. The value range is **1** to **9**.
               - PricingCycle is **Year**, indicating annual payment. The value range is **1** to **3**.
               
               When the value of> ChargeType is **PrePaid**, this parameter is available and must be passed in.
        :param pulumi.Input[bool] egress_ipv6_enable: Specifies whether IPv6 egress capability is enabled.
        :param pulumi.Input[str] https_policy: Https policy.
        :param pulumi.Input[str] instance_cidr: The CIDR block for the instance deployment. Valid values are:
               - `192.168.0.0/16`.
               - `172.16.0.0/12`.
        :param pulumi.Input[str] instance_name: Instance name.
        :param pulumi.Input[str] instance_spec: Instance type.
        :param pulumi.Input[str] instance_type: The type of the instance. Valid values are:
        :param pulumi.Input[bool] ipv6_enabled: Specifies whether IPv6 ingress capability is enabled.
        :param pulumi.Input[str] payment_type: The payment type of the resource.
        :param pulumi.Input[str] pricing_cycle: The subscription instance is of the subscription year or month type. This parameter is required when the Payment type is PrePaid. The value range is as follows:
        :param pulumi.Input[str] status: The status of the resource.
        :param pulumi.Input[bool] support_ipv6: Does ipv6 support.
        :param pulumi.Input[Union['InstanceToConnectVpcIpBlockArgs', 'InstanceToConnectVpcIpBlockArgsDict']] to_connect_vpc_ip_block: The additional IP block that the VPC integration instance can access, conflict with `delete_vpc_ip_block`. See `to_connect_vpc_ip_block` below.
        :param pulumi.Input[str] user_vpc_id: User's VpcID.
        :param pulumi.Input[bool] vpc_slb_intranet_enable: Whether the slb of the Vpc supports.
        :param pulumi.Input[str] zone_id: The zone where the instance is deployed.
        :param pulumi.Input[Sequence[pulumi.Input[Union['InstanceZoneVswitchSecurityGroupArgs', 'InstanceZoneVswitchSecurityGroupArgsDict']]]] zone_vswitch_security_groups: Network configuration details for Vpc integration instance which includes the availability zone, VSwitch, and security group information. See `zone_vswitch_security_group` below.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["connect_cidr_blocks"] = connect_cidr_blocks
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["delete_vpc_ip_block"] = delete_vpc_ip_block
        __props__.__dict__["duration"] = duration
        __props__.__dict__["egress_ipv6_enable"] = egress_ipv6_enable
        __props__.__dict__["https_policy"] = https_policy
        __props__.__dict__["instance_cidr"] = instance_cidr
        __props__.__dict__["instance_name"] = instance_name
        __props__.__dict__["instance_spec"] = instance_spec
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["ipv6_enabled"] = ipv6_enabled
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["pricing_cycle"] = pricing_cycle
        __props__.__dict__["status"] = status
        __props__.__dict__["support_ipv6"] = support_ipv6
        __props__.__dict__["to_connect_vpc_ip_block"] = to_connect_vpc_ip_block
        __props__.__dict__["user_vpc_id"] = user_vpc_id
        __props__.__dict__["vpc_slb_intranet_enable"] = vpc_slb_intranet_enable
        __props__.__dict__["zone_id"] = zone_id
        __props__.__dict__["zone_vswitch_security_groups"] = zone_vswitch_security_groups
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="connectCidrBlocks")
    def connect_cidr_blocks(self) -> pulumi.Output[str]:
        """
        (Available since v1.228.0) The CIDR blocks that can be accessed by the Vpc integration instance.
        """
        return pulumi.get(self, "connect_cidr_blocks")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="deleteVpcIpBlock")
    def delete_vpc_ip_block(self) -> pulumi.Output[Optional[str]]:
        """
        Indicates whether to delete the IP block that the VPC can access, conflict with `to_connect_vpc_ip_block`.
        """
        return pulumi.get(self, "delete_vpc_ip_block")

    @property
    @pulumi.getter
    def duration(self) -> pulumi.Output[Optional[int]]:
        """
        The time of the instance package. Valid values:
        - PricingCycle is **Month**, indicating monthly payment. The value range is **1** to **9**.
        - PricingCycle is **Year**, indicating annual payment. The value range is **1** to **3**.

        When the value of> ChargeType is **PrePaid**, this parameter is available and must be passed in.
        """
        return pulumi.get(self, "duration")

    @property
    @pulumi.getter(name="egressIpv6Enable")
    def egress_ipv6_enable(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether IPv6 egress capability is enabled.
        """
        return pulumi.get(self, "egress_ipv6_enable")

    @property
    @pulumi.getter(name="httpsPolicy")
    def https_policy(self) -> pulumi.Output[str]:
        """
        Https policy.
        """
        return pulumi.get(self, "https_policy")

    @property
    @pulumi.getter(name="instanceCidr")
    def instance_cidr(self) -> pulumi.Output[str]:
        """
        The CIDR block for the instance deployment. Valid values are:
        - `192.168.0.0/16`.
        - `172.16.0.0/12`.
        """
        return pulumi.get(self, "instance_cidr")

    @property
    @pulumi.getter(name="instanceName")
    def instance_name(self) -> pulumi.Output[str]:
        """
        Instance name.
        """
        return pulumi.get(self, "instance_name")

    @property
    @pulumi.getter(name="instanceSpec")
    def instance_spec(self) -> pulumi.Output[str]:
        """
        Instance type.
        """
        return pulumi.get(self, "instance_spec")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[str]:
        """
        The type of the instance. Valid values are:
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="ipv6Enabled")
    def ipv6_enabled(self) -> pulumi.Output[Optional[bool]]:
        """
        Specifies whether IPv6 ingress capability is enabled.
        """
        return pulumi.get(self, "ipv6_enabled")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[str]:
        """
        The payment type of the resource.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter(name="pricingCycle")
    def pricing_cycle(self) -> pulumi.Output[Optional[str]]:
        """
        The subscription instance is of the subscription year or month type. This parameter is required when the Payment type is PrePaid. The value range is as follows:
        """
        return pulumi.get(self, "pricing_cycle")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="supportIpv6")
    def support_ipv6(self) -> pulumi.Output[bool]:
        """
        Does ipv6 support.
        """
        return pulumi.get(self, "support_ipv6")

    @property
    @pulumi.getter(name="toConnectVpcIpBlock")
    def to_connect_vpc_ip_block(self) -> pulumi.Output[Optional['outputs.InstanceToConnectVpcIpBlock']]:
        """
        The additional IP block that the VPC integration instance can access, conflict with `delete_vpc_ip_block`. See `to_connect_vpc_ip_block` below.
        """
        return pulumi.get(self, "to_connect_vpc_ip_block")

    @property
    @pulumi.getter(name="userVpcId")
    def user_vpc_id(self) -> pulumi.Output[Optional[str]]:
        """
        User's VpcID.
        """
        return pulumi.get(self, "user_vpc_id")

    @property
    @pulumi.getter(name="vpcSlbIntranetEnable")
    def vpc_slb_intranet_enable(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether the slb of the Vpc supports.
        """
        return pulumi.get(self, "vpc_slb_intranet_enable")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[str]:
        """
        The zone where the instance is deployed.
        """
        return pulumi.get(self, "zone_id")

    @property
    @pulumi.getter(name="zoneVswitchSecurityGroups")
    def zone_vswitch_security_groups(self) -> pulumi.Output[Optional[Sequence['outputs.InstanceZoneVswitchSecurityGroup']]]:
        """
        Network configuration details for Vpc integration instance which includes the availability zone, VSwitch, and security group information. See `zone_vswitch_security_group` below.
        """
        return pulumi.get(self, "zone_vswitch_security_groups")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetBackupPoliciesResult',
    'AwaitableGetBackupPoliciesResult',
    'get_backup_policies',
    'get_backup_policies_output',
]

@pulumi.output_type
class GetBackupPoliciesResult:
    """
    A collection of values returned by getBackupPolicies.
    """
    def __init__(__self__, current_page=None, id=None, ids=None, machine_remark=None, name=None, name_regex=None, names=None, output_file=None, page_size=None, policies=None, status=None):
        if current_page and not isinstance(current_page, int):
            raise TypeError("Expected argument 'current_page' to be a int")
        pulumi.set(__self__, "current_page", current_page)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if machine_remark and not isinstance(machine_remark, str):
            raise TypeError("Expected argument 'machine_remark' to be a str")
        pulumi.set(__self__, "machine_remark", machine_remark)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if policies and not isinstance(policies, list):
            raise TypeError("Expected argument 'policies' to be a list")
        pulumi.set(__self__, "policies", policies)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="currentPage")
    def current_page(self) -> Optional[int]:
        return pulumi.get(self, "current_page")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="machineRemark")
    def machine_remark(self) -> Optional[str]:
        return pulumi.get(self, "machine_remark")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        """
        A list of Threat Detection Backup Policy names.
        """
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter
    def policies(self) -> Sequence['outputs.GetBackupPoliciesPolicyResult']:
        """
        A list of Threat Detection Backup policies. Each element contains the following attributes:
        """
        return pulumi.get(self, "policies")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        """
        The status of the anti-ransomware policy.
        """
        return pulumi.get(self, "status")


class AwaitableGetBackupPoliciesResult(GetBackupPoliciesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBackupPoliciesResult(
            current_page=self.current_page,
            id=self.id,
            ids=self.ids,
            machine_remark=self.machine_remark,
            name=self.name,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            page_size=self.page_size,
            policies=self.policies,
            status=self.status)


def get_backup_policies(current_page: Optional[int] = None,
                        ids: Optional[Sequence[str]] = None,
                        machine_remark: Optional[str] = None,
                        name: Optional[str] = None,
                        name_regex: Optional[str] = None,
                        output_file: Optional[str] = None,
                        page_size: Optional[int] = None,
                        status: Optional[str] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBackupPoliciesResult:
    """
    This data source provides the Threat Detection Backup Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.195.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.threatdetection.get_backup_policies(ids=["example_id"])
    pulumi.export("threatDetectionBackupPoliciesId1", ids.policies[0].id)
    name_regex = alicloud.threatdetection.get_backup_policies(name_regex="tf-example")
    pulumi.export("threatDetectionBackupPoliciesId2", name_regex.policies[0].id)
    ```


    :param Sequence[str] ids: A list of Threat Detection Backup Policies IDs.
    :param str machine_remark: The information that you want to use to identify the servers protected by the anti-ransomware policy. You can enter the IP address or ID of a server.
    :param str name: The name of the anti-ransomware policy that you want to query.
    :param str name_regex: A regex string to filter results by Threat Detection Backup Policies name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the anti-ransomware policy. Valid Value: `enabled`, `disabled`, `closed`.
    """
    __args__ = dict()
    __args__['currentPage'] = current_page
    __args__['ids'] = ids
    __args__['machineRemark'] = machine_remark
    __args__['name'] = name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageSize'] = page_size
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:threatdetection/getBackupPolicies:getBackupPolicies', __args__, opts=opts, typ=GetBackupPoliciesResult).value

    return AwaitableGetBackupPoliciesResult(
        current_page=pulumi.get(__ret__, 'current_page'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        machine_remark=pulumi.get(__ret__, 'machine_remark'),
        name=pulumi.get(__ret__, 'name'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_size=pulumi.get(__ret__, 'page_size'),
        policies=pulumi.get(__ret__, 'policies'),
        status=pulumi.get(__ret__, 'status'))
def get_backup_policies_output(current_page: Optional[pulumi.Input[Optional[int]]] = None,
                               ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                               machine_remark: Optional[pulumi.Input[Optional[str]]] = None,
                               name: Optional[pulumi.Input[Optional[str]]] = None,
                               name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                               output_file: Optional[pulumi.Input[Optional[str]]] = None,
                               page_size: Optional[pulumi.Input[Optional[int]]] = None,
                               status: Optional[pulumi.Input[Optional[str]]] = None,
                               opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetBackupPoliciesResult]:
    """
    This data source provides the Threat Detection Backup Policies of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.195.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    ids = alicloud.threatdetection.get_backup_policies(ids=["example_id"])
    pulumi.export("threatDetectionBackupPoliciesId1", ids.policies[0].id)
    name_regex = alicloud.threatdetection.get_backup_policies(name_regex="tf-example")
    pulumi.export("threatDetectionBackupPoliciesId2", name_regex.policies[0].id)
    ```


    :param Sequence[str] ids: A list of Threat Detection Backup Policies IDs.
    :param str machine_remark: The information that you want to use to identify the servers protected by the anti-ransomware policy. You can enter the IP address or ID of a server.
    :param str name: The name of the anti-ransomware policy that you want to query.
    :param str name_regex: A regex string to filter results by Threat Detection Backup Policies name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: The status of the anti-ransomware policy. Valid Value: `enabled`, `disabled`, `closed`.
    """
    __args__ = dict()
    __args__['currentPage'] = current_page
    __args__['ids'] = ids
    __args__['machineRemark'] = machine_remark
    __args__['name'] = name
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['pageSize'] = page_size
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:threatdetection/getBackupPolicies:getBackupPolicies', __args__, opts=opts, typ=GetBackupPoliciesResult)
    return __ret__.apply(lambda __response__: GetBackupPoliciesResult(
        current_page=pulumi.get(__response__, 'current_page'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        machine_remark=pulumi.get(__response__, 'machine_remark'),
        name=pulumi.get(__response__, 'name'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_size=pulumi.get(__response__, 'page_size'),
        policies=pulumi.get(__response__, 'policies'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AccessKeyArgs', 'AccessKey']

@pulumi.input_type
class AccessKeyArgs:
    def __init__(__self__, *,
                 pgp_key: Optional[pulumi.Input[str]] = None,
                 secret_file: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 user_name: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a AccessKey resource.
        :param pulumi.Input[str] pgp_key: Either a base-64 encoded PGP public key, or a keybase username in the form `keybase:some_person_that_exists`
        :param pulumi.Input[str] secret_file: The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        :param pulumi.Input[str] status: Status of access key. It must be `Active` or `Inactive`. Default value is `Active`.
        :param pulumi.Input[str] user_name: Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        """
        if pgp_key is not None:
            pulumi.set(__self__, "pgp_key", pgp_key)
        if secret_file is not None:
            pulumi.set(__self__, "secret_file", secret_file)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="pgpKey")
    def pgp_key(self) -> Optional[pulumi.Input[str]]:
        """
        Either a base-64 encoded PGP public key, or a keybase username in the form `keybase:some_person_that_exists`
        """
        return pulumi.get(self, "pgp_key")

    @pgp_key.setter
    def pgp_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pgp_key", value)

    @property
    @pulumi.getter(name="secretFile")
    def secret_file(self) -> Optional[pulumi.Input[str]]:
        """
        The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        """
        return pulumi.get(self, "secret_file")

    @secret_file.setter
    def secret_file(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret_file", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Status of access key. It must be `Active` or `Inactive`. Default value is `Active`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_name", value)


@pulumi.input_type
class _AccessKeyState:
    def __init__(__self__, *,
                 encrypted_secret: Optional[pulumi.Input[str]] = None,
                 key_fingerprint: Optional[pulumi.Input[str]] = None,
                 pgp_key: Optional[pulumi.Input[str]] = None,
                 secret: Optional[pulumi.Input[str]] = None,
                 secret_file: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 user_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering AccessKey resources.
        :param pulumi.Input[str] key_fingerprint: The fingerprint of the PGP key used to encrypt the secret
        :param pulumi.Input[str] pgp_key: Either a base-64 encoded PGP public key, or a keybase username in the form `keybase:some_person_that_exists`
        :param pulumi.Input[str] secret: (Available since 1.98.0+) - The secret access key. Note that this will be written to the state file. 
               If you use this, please protect your backend state file judiciously.
               Alternatively, you may supply a `pgp_key` instead, which will prevent the secret from being stored in plaintext,
               at the cost of preventing the use of the secret key in automation.
        :param pulumi.Input[str] secret_file: The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        :param pulumi.Input[str] status: Status of access key. It must be `Active` or `Inactive`. Default value is `Active`.
        :param pulumi.Input[str] user_name: Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        """
        if encrypted_secret is not None:
            pulumi.set(__self__, "encrypted_secret", encrypted_secret)
        if key_fingerprint is not None:
            pulumi.set(__self__, "key_fingerprint", key_fingerprint)
        if pgp_key is not None:
            pulumi.set(__self__, "pgp_key", pgp_key)
        if secret is not None:
            pulumi.set(__self__, "secret", secret)
        if secret_file is not None:
            pulumi.set(__self__, "secret_file", secret_file)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if user_name is not None:
            pulumi.set(__self__, "user_name", user_name)

    @property
    @pulumi.getter(name="encryptedSecret")
    def encrypted_secret(self) -> Optional[pulumi.Input[str]]:
        return pulumi.get(self, "encrypted_secret")

    @encrypted_secret.setter
    def encrypted_secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "encrypted_secret", value)

    @property
    @pulumi.getter(name="keyFingerprint")
    def key_fingerprint(self) -> Optional[pulumi.Input[str]]:
        """
        The fingerprint of the PGP key used to encrypt the secret
        """
        return pulumi.get(self, "key_fingerprint")

    @key_fingerprint.setter
    def key_fingerprint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "key_fingerprint", value)

    @property
    @pulumi.getter(name="pgpKey")
    def pgp_key(self) -> Optional[pulumi.Input[str]]:
        """
        Either a base-64 encoded PGP public key, or a keybase username in the form `keybase:some_person_that_exists`
        """
        return pulumi.get(self, "pgp_key")

    @pgp_key.setter
    def pgp_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "pgp_key", value)

    @property
    @pulumi.getter
    def secret(self) -> Optional[pulumi.Input[str]]:
        """
        (Available since 1.98.0+) - The secret access key. Note that this will be written to the state file. 
        If you use this, please protect your backend state file judiciously.
        Alternatively, you may supply a `pgp_key` instead, which will prevent the secret from being stored in plaintext,
        at the cost of preventing the use of the secret key in automation.
        """
        return pulumi.get(self, "secret")

    @secret.setter
    def secret(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret", value)

    @property
    @pulumi.getter(name="secretFile")
    def secret_file(self) -> Optional[pulumi.Input[str]]:
        """
        The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        """
        return pulumi.get(self, "secret_file")

    @secret_file.setter
    def secret_file(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret_file", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        Status of access key. It must be `Active` or `Inactive`. Default value is `Active`.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        """
        return pulumi.get(self, "user_name")

    @user_name.setter
    def user_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "user_name", value)


class AccessKey(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 pgp_key: Optional[pulumi.Input[str]] = None,
                 secret_file: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 user_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a RAM User access key resource.

        > **NOTE:**  You should set the `secret_file` if you want to get the access key.

        > **NOTE:**  From version 1.98.0, if not set `pgp_key`, the resource will output the access key secret to field `secret` and please protect your backend state file judiciously

        > **NOTE:** Available since v1.0.0+.

        ## Example Usage

        Output the secret to a file.

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        # Create a new RAM access key for user.
        user = alicloud.ram.User("user",
            name="terraform-example",
            display_name="user_display_name",
            mobile="86-18688888888",
            email="hello.uuu@aaa.com",
            comments="yoyoyo",
            force=True)
        ak = alicloud.ram.AccessKey("ak",
            user_name=user.name,
            secret_file="/xxx/xxx/xxx.txt")
        ```

        Using `pgp_key` to encrypt the secret.

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        # Create a new RAM access key for user.
        user = alicloud.ram.User("user",
            name="terraform-example",
            display_name="user_display_name",
            mobile="86-18688888888",
            email="hello.uuu@aaa.com",
            comments="yoyoyo",
            force=True)
        encrypt = alicloud.ram.AccessKey("encrypt",
            user_name=user.name,
            pgp_key=\"\"\"mQENBFXbjPUBCADjNjCUQwfxKL+RR2GA6pv/1K+zJZ8UWIF9S0lk7cVIEfJiprzzwiMwBS5cD0da
        rGin1FHvIWOZxujA7oW0O2TUuatqI3aAYDTfRYurh6iKLC+VS+F7H+/mhfFvKmgr0Y5kDCF1j0T/
        063QZ84IRGucR/X43IY7kAtmxGXH0dYOCzOe5UBX1fTn3mXGe2ImCDWBH7gOViynXmb6XNvXkP0f
        sF5St9jhO7mbZU9EFkv9O3t3EaURfHopsCVDOlCkFCw5ArY+DUORHRzoMX0PnkyQb5OzibkChzpg
        8hQssKeVGpuskTdz5Q7PtdW71jXd4fFVzoNH8fYwRpziD2xNvi6HABEBAAG0EFZhdWx0IFRlc3Qg
        S2V5IDGJATgEEwECACIFAlXbjPUCGy8GCwkIBwMCBhUIAgkKCwQWAgMBAh4BAheAAAoJEOfLr44B
        HbeTo+sH/i7bapIgPnZsJ81hmxPj4W12uvunksGJiC7d4hIHsG7kmJRTJfjECi+AuTGeDwBy84TD
        cRaOB6e79fj65Fg6HgSahDUtKJbGxj/lWzmaBuTzlN3CEe8cMwIPqPT2kajJVdOyrvkyuFOdPFOE
        A7bdCH0MqgIdM2SdF8t40k/ATfuD2K1ZmumJ508I3gF39jgTnPzD4C8quswrMQ3bzfvKC3klXRlB
        C0yoArn+0QA3cf2B9T4zJ2qnvgotVbeK/b1OJRNj6Poeo+SsWNc/A5mw7lGScnDgL3yfwCm1gQXa
        QKfOt5x+7GqhWDw10q+bJpJlI10FfzAnhMF9etSqSeURBRW5AQ0EVduM9QEIAL53hJ5bZJ7oEDCn
        aY+SCzt9QsAfnFTAnZJQrvkvusJzrTQ088eUQmAjvxkfRqnv981fFwGnh2+I1Ktm698UAZS9Jt8y
        jak9wWUICKQO5QUt5k8cHwldQXNXVXFa+TpQWQR5yW1a9okjh5o/3d4cBt1yZPUJJyLKY43Wvptb
        6EuEsScO2DnRkh5wSMDQ7dTooddJCmaq3LTjOleRFQbu9ij386Do6jzK69mJU56TfdcydkxkWF5N
        ZLGnED3lq+hQNbe+8UI5tD2oP/3r5tXKgMy1R/XPvR/zbfwvx4FAKFOP01awLq4P3d/2xOkMu4Lu
        9p315E87DOleYwxk+FoTqXEAEQEAAYkCPgQYAQIACQUCVduM9QIbLgEpCRDny6+OAR23k8BdIAQZ
        AQIABgUCVduM9QAKCRAID0JGyHtSGmqYB/4m4rJbbWa7dBJ8VqRU7ZKnNRDR9CVhEGipBmpDGRYu
        lEimOPzLUX/ZXZmTZzgemeXLBaJJlWnopVUWuAsyjQuZAfdd8nHkGRHG0/DGum0l4sKTta3OPGHN
        C1z1dAcQ1RCr9bTD3PxjLBczdGqhzw71trkQRBRdtPiUchltPMIyjUHqVJ0xmg0hPqFic0fICsr0
        YwKoz3h9+QEcZHvsjSZjgydKvfLYcm+4DDMCCqcHuJrbXJKUWmJcXR0y/+HQONGrGJ5xWdO+6eJi
        oPn2jVMnXCm4EKc7fcLFrz/LKmJ8seXhxjM3EdFtylBGCrx3xdK0f+JDNQaC/rhUb5V2XuX6VwoH
        /AtY+XsKVYRfNIupLOUcf/srsm3IXT4SXWVomOc9hjGQiJ3rraIbADsc+6bCAr4XNZS7moViAAcI
        PXFv3m3WfUlnG/om78UjQqyVACRZqqAGmuPq+TSkRUCpt9h+A39LQWkojHqyob3cyLgy6z9Q557O
        9uK3lQozbw2gH9zC0RqnePl+rsWIUU/ga16fH6pWc1uJiEBt8UZGypQ/E56/343epmYAe0a87sHx
        8iDV+dNtDVKfPRENiLOOc19MmS+phmUyrbHqI91c0pmysYcJZCD3a502X1gpjFbPZcRtiTmGnUKd
        OIu60YPNE4+h7u2CfYyFPu3AlUaGNMBlvy6PEpU=
        \"\"\")
        pulumi.export("secret", encrypt.encrypted_secret)
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] pgp_key: Either a base-64 encoded PGP public key, or a keybase username in the form `keybase:some_person_that_exists`
        :param pulumi.Input[str] secret_file: The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        :param pulumi.Input[str] status: Status of access key. It must be `Active` or `Inactive`. Default value is `Active`.
        :param pulumi.Input[str] user_name: Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AccessKeyArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a RAM User access key resource.

        > **NOTE:**  You should set the `secret_file` if you want to get the access key.

        > **NOTE:**  From version 1.98.0, if not set `pgp_key`, the resource will output the access key secret to field `secret` and please protect your backend state file judiciously

        > **NOTE:** Available since v1.0.0+.

        ## Example Usage

        Output the secret to a file.

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        # Create a new RAM access key for user.
        user = alicloud.ram.User("user",
            name="terraform-example",
            display_name="user_display_name",
            mobile="86-18688888888",
            email="hello.uuu@aaa.com",
            comments="yoyoyo",
            force=True)
        ak = alicloud.ram.AccessKey("ak",
            user_name=user.name,
            secret_file="/xxx/xxx/xxx.txt")
        ```

        Using `pgp_key` to encrypt the secret.

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        # Create a new RAM access key for user.
        user = alicloud.ram.User("user",
            name="terraform-example",
            display_name="user_display_name",
            mobile="86-18688888888",
            email="hello.uuu@aaa.com",
            comments="yoyoyo",
            force=True)
        encrypt = alicloud.ram.AccessKey("encrypt",
            user_name=user.name,
            pgp_key=\"\"\"mQENBFXbjPUBCADjNjCUQwfxKL+RR2GA6pv/1K+zJZ8UWIF9S0lk7cVIEfJiprzzwiMwBS5cD0da
        rGin1FHvIWOZxujA7oW0O2TUuatqI3aAYDTfRYurh6iKLC+VS+F7H+/mhfFvKmgr0Y5kDCF1j0T/
        063QZ84IRGucR/X43IY7kAtmxGXH0dYOCzOe5UBX1fTn3mXGe2ImCDWBH7gOViynXmb6XNvXkP0f
        sF5St9jhO7mbZU9EFkv9O3t3EaURfHopsCVDOlCkFCw5ArY+DUORHRzoMX0PnkyQb5OzibkChzpg
        8hQssKeVGpuskTdz5Q7PtdW71jXd4fFVzoNH8fYwRpziD2xNvi6HABEBAAG0EFZhdWx0IFRlc3Qg
        S2V5IDGJATgEEwECACIFAlXbjPUCGy8GCwkIBwMCBhUIAgkKCwQWAgMBAh4BAheAAAoJEOfLr44B
        HbeTo+sH/i7bapIgPnZsJ81hmxPj4W12uvunksGJiC7d4hIHsG7kmJRTJfjECi+AuTGeDwBy84TD
        cRaOB6e79fj65Fg6HgSahDUtKJbGxj/lWzmaBuTzlN3CEe8cMwIPqPT2kajJVdOyrvkyuFOdPFOE
        A7bdCH0MqgIdM2SdF8t40k/ATfuD2K1ZmumJ508I3gF39jgTnPzD4C8quswrMQ3bzfvKC3klXRlB
        C0yoArn+0QA3cf2B9T4zJ2qnvgotVbeK/b1OJRNj6Poeo+SsWNc/A5mw7lGScnDgL3yfwCm1gQXa
        QKfOt5x+7GqhWDw10q+bJpJlI10FfzAnhMF9etSqSeURBRW5AQ0EVduM9QEIAL53hJ5bZJ7oEDCn
        aY+SCzt9QsAfnFTAnZJQrvkvusJzrTQ088eUQmAjvxkfRqnv981fFwGnh2+I1Ktm698UAZS9Jt8y
        jak9wWUICKQO5QUt5k8cHwldQXNXVXFa+TpQWQR5yW1a9okjh5o/3d4cBt1yZPUJJyLKY43Wvptb
        6EuEsScO2DnRkh5wSMDQ7dTooddJCmaq3LTjOleRFQbu9ij386Do6jzK69mJU56TfdcydkxkWF5N
        ZLGnED3lq+hQNbe+8UI5tD2oP/3r5tXKgMy1R/XPvR/zbfwvx4FAKFOP01awLq4P3d/2xOkMu4Lu
        9p315E87DOleYwxk+FoTqXEAEQEAAYkCPgQYAQIACQUCVduM9QIbLgEpCRDny6+OAR23k8BdIAQZ
        AQIABgUCVduM9QAKCRAID0JGyHtSGmqYB/4m4rJbbWa7dBJ8VqRU7ZKnNRDR9CVhEGipBmpDGRYu
        lEimOPzLUX/ZXZmTZzgemeXLBaJJlWnopVUWuAsyjQuZAfdd8nHkGRHG0/DGum0l4sKTta3OPGHN
        C1z1dAcQ1RCr9bTD3PxjLBczdGqhzw71trkQRBRdtPiUchltPMIyjUHqVJ0xmg0hPqFic0fICsr0
        YwKoz3h9+QEcZHvsjSZjgydKvfLYcm+4DDMCCqcHuJrbXJKUWmJcXR0y/+HQONGrGJ5xWdO+6eJi
        oPn2jVMnXCm4EKc7fcLFrz/LKmJ8seXhxjM3EdFtylBGCrx3xdK0f+JDNQaC/rhUb5V2XuX6VwoH
        /AtY+XsKVYRfNIupLOUcf/srsm3IXT4SXWVomOc9hjGQiJ3rraIbADsc+6bCAr4XNZS7moViAAcI
        PXFv3m3WfUlnG/om78UjQqyVACRZqqAGmuPq+TSkRUCpt9h+A39LQWkojHqyob3cyLgy6z9Q557O
        9uK3lQozbw2gH9zC0RqnePl+rsWIUU/ga16fH6pWc1uJiEBt8UZGypQ/E56/343epmYAe0a87sHx
        8iDV+dNtDVKfPRENiLOOc19MmS+phmUyrbHqI91c0pmysYcJZCD3a502X1gpjFbPZcRtiTmGnUKd
        OIu60YPNE4+h7u2CfYyFPu3AlUaGNMBlvy6PEpU=
        \"\"\")
        pulumi.export("secret", encrypt.encrypted_secret)
        ```

        :param str resource_name: The name of the resource.
        :param AccessKeyArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AccessKeyArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 pgp_key: Optional[pulumi.Input[str]] = None,
                 secret_file: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 user_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AccessKeyArgs.__new__(AccessKeyArgs)

            __props__.__dict__["pgp_key"] = pgp_key
            __props__.__dict__["secret_file"] = secret_file
            __props__.__dict__["status"] = status
            __props__.__dict__["user_name"] = user_name
            __props__.__dict__["encrypted_secret"] = None
            __props__.__dict__["key_fingerprint"] = None
            __props__.__dict__["secret"] = None
        secret_opts = pulumi.ResourceOptions(additional_secret_outputs=["secret"])
        opts = pulumi.ResourceOptions.merge(opts, secret_opts)
        super(AccessKey, __self__).__init__(
            'alicloud:ram/accessKey:AccessKey',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            encrypted_secret: Optional[pulumi.Input[str]] = None,
            key_fingerprint: Optional[pulumi.Input[str]] = None,
            pgp_key: Optional[pulumi.Input[str]] = None,
            secret: Optional[pulumi.Input[str]] = None,
            secret_file: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            user_name: Optional[pulumi.Input[str]] = None) -> 'AccessKey':
        """
        Get an existing AccessKey resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] key_fingerprint: The fingerprint of the PGP key used to encrypt the secret
        :param pulumi.Input[str] pgp_key: Either a base-64 encoded PGP public key, or a keybase username in the form `keybase:some_person_that_exists`
        :param pulumi.Input[str] secret: (Available since 1.98.0+) - The secret access key. Note that this will be written to the state file. 
               If you use this, please protect your backend state file judiciously.
               Alternatively, you may supply a `pgp_key` instead, which will prevent the secret from being stored in plaintext,
               at the cost of preventing the use of the secret key in automation.
        :param pulumi.Input[str] secret_file: The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        :param pulumi.Input[str] status: Status of access key. It must be `Active` or `Inactive`. Default value is `Active`.
        :param pulumi.Input[str] user_name: Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AccessKeyState.__new__(_AccessKeyState)

        __props__.__dict__["encrypted_secret"] = encrypted_secret
        __props__.__dict__["key_fingerprint"] = key_fingerprint
        __props__.__dict__["pgp_key"] = pgp_key
        __props__.__dict__["secret"] = secret
        __props__.__dict__["secret_file"] = secret_file
        __props__.__dict__["status"] = status
        __props__.__dict__["user_name"] = user_name
        return AccessKey(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="encryptedSecret")
    def encrypted_secret(self) -> pulumi.Output[str]:
        return pulumi.get(self, "encrypted_secret")

    @property
    @pulumi.getter(name="keyFingerprint")
    def key_fingerprint(self) -> pulumi.Output[str]:
        """
        The fingerprint of the PGP key used to encrypt the secret
        """
        return pulumi.get(self, "key_fingerprint")

    @property
    @pulumi.getter(name="pgpKey")
    def pgp_key(self) -> pulumi.Output[Optional[str]]:
        """
        Either a base-64 encoded PGP public key, or a keybase username in the form `keybase:some_person_that_exists`
        """
        return pulumi.get(self, "pgp_key")

    @property
    @pulumi.getter
    def secret(self) -> pulumi.Output[str]:
        """
        (Available since 1.98.0+) - The secret access key. Note that this will be written to the state file. 
        If you use this, please protect your backend state file judiciously.
        Alternatively, you may supply a `pgp_key` instead, which will prevent the secret from being stored in plaintext,
        at the cost of preventing the use of the secret key in automation.
        """
        return pulumi.get(self, "secret")

    @property
    @pulumi.getter(name="secretFile")
    def secret_file(self) -> pulumi.Output[Optional[str]]:
        """
        The name of file that can save access key id and access key secret. Strongly suggest you to specified it when you creating access key, otherwise, you wouldn't get its secret ever.
        """
        return pulumi.get(self, "secret_file")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[Optional[str]]:
        """
        Status of access key. It must be `Active` or `Inactive`. Default value is `Active`.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="userName")
    def user_name(self) -> pulumi.Output[Optional[str]]:
        """
        Name of the RAM user. This name can have a string of 1 to 64 characters, must contain only alphanumeric characters or hyphens, such as "-",".","_", and must not begin with a hyphen.
        """
        return pulumi.get(self, "user_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetGatewayVcoRoutesResult',
    'AwaitableGetGatewayVcoRoutesResult',
    'get_gateway_vco_routes',
    'get_gateway_vco_routes_output',
]

@pulumi.output_type
class GetGatewayVcoRoutesResult:
    """
    A collection of values returned by getGatewayVcoRoutes.
    """
    def __init__(__self__, id=None, ids=None, output_file=None, page_number=None, page_size=None, route_entry_type=None, routes=None, status=None, vpn_connection_id=None):
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if page_number and not isinstance(page_number, int):
            raise TypeError("Expected argument 'page_number' to be a int")
        pulumi.set(__self__, "page_number", page_number)
        if page_size and not isinstance(page_size, int):
            raise TypeError("Expected argument 'page_size' to be a int")
        pulumi.set(__self__, "page_size", page_size)
        if route_entry_type and not isinstance(route_entry_type, str):
            raise TypeError("Expected argument 'route_entry_type' to be a str")
        pulumi.set(__self__, "route_entry_type", route_entry_type)
        if routes and not isinstance(routes, list):
            raise TypeError("Expected argument 'routes' to be a list")
        pulumi.set(__self__, "routes", routes)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if vpn_connection_id and not isinstance(vpn_connection_id, str):
            raise TypeError("Expected argument 'vpn_connection_id' to be a str")
        pulumi.set(__self__, "vpn_connection_id", vpn_connection_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="pageNumber")
    def page_number(self) -> Optional[int]:
        return pulumi.get(self, "page_number")

    @property
    @pulumi.getter(name="pageSize")
    def page_size(self) -> Optional[int]:
        return pulumi.get(self, "page_size")

    @property
    @pulumi.getter(name="routeEntryType")
    def route_entry_type(self) -> Optional[str]:
        return pulumi.get(self, "route_entry_type")

    @property
    @pulumi.getter
    def routes(self) -> Sequence['outputs.GetGatewayVcoRoutesRouteResult']:
        return pulumi.get(self, "routes")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpnConnectionId")
    def vpn_connection_id(self) -> str:
        return pulumi.get(self, "vpn_connection_id")


class AwaitableGetGatewayVcoRoutesResult(GetGatewayVcoRoutesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetGatewayVcoRoutesResult(
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            page_number=self.page_number,
            page_size=self.page_size,
            route_entry_type=self.route_entry_type,
            routes=self.routes,
            status=self.status,
            vpn_connection_id=self.vpn_connection_id)


def get_gateway_vco_routes(ids: Optional[Sequence[str]] = None,
                           output_file: Optional[str] = None,
                           page_number: Optional[int] = None,
                           page_size: Optional[int] = None,
                           route_entry_type: Optional[str] = None,
                           status: Optional[str] = None,
                           vpn_connection_id: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetGatewayVcoRoutesResult:
    """
    This data source provides the Vpn Gateway Vco Routes of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.183.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default_instance = alicloud.cen.Instance("default", cen_instance_name=name)
    default_transit_router = alicloud.cen.TransitRouter("default",
        cen_id=default_instance.id,
        transit_router_description="desd",
        transit_router_name=name)
    default = alicloud.cen.get_transit_router_available_resources()
    default_customer_gateway = alicloud.vpn.CustomerGateway("default",
        name=name,
        ip_address="42.104.22.210",
        asn="45014",
        description="testAccVpnConnectionDesc")
    default_gateway_vpn_attachment = alicloud.vpn.GatewayVpnAttachment("default",
        customer_gateway_id=default_customer_gateway.id,
        network_type="public",
        local_subnet="0.0.0.0/0",
        remote_subnet="0.0.0.0/0",
        effect_immediately=False,
        ike_config={
            "ike_auth_alg": "md5",
            "ike_enc_alg": "des",
            "ike_version": "ikev2",
            "ike_mode": "main",
            "ike_lifetime": 86400,
            "psk": "tf-testvpn2",
            "ike_pfs": "group1",
            "remote_id": "testbob2",
            "local_id": "testalice2",
        },
        ipsec_config={
            "ipsec_pfs": "group5",
            "ipsec_enc_alg": "des",
            "ipsec_auth_alg": "md5",
            "ipsec_lifetime": 86400,
        },
        bgp_config={
            "enable": True,
            "local_asn": 45014,
            "tunnel_cidr": "169.254.11.0/30",
            "local_bgp_ip": "169.254.11.1",
        },
        health_check_config={
            "enable": True,
            "sip": "192.168.1.1",
            "dip": "10.0.0.1",
            "interval": 10,
            "retry": 10,
            "policy": "revoke_route",
        },
        enable_dpd=True,
        enable_nat_traversal=True,
        vpn_attachment_name=name)
    default_transit_router_vpn_attachment = alicloud.cen.TransitRouterVpnAttachment("default",
        auto_publish_route_enabled=False,
        transit_router_attachment_description=name,
        transit_router_attachment_name=name,
        cen_id=default_transit_router.cen_id,
        transit_router_id=default_transit_router.transit_router_id,
        vpn_id=default_gateway_vpn_attachment.id,
        zones=[{
            "zone_id": default.resources[0].master_zones[0],
        }])
    default_gateway_vco_route = alicloud.vpn.GatewayVcoRoute("default",
        route_dest="192.168.12.0/24",
        next_hop=default_transit_router_vpn_attachment.vpn_id,
        vpn_connection_id=default_transit_router_vpn_attachment.vpn_id,
        weight=100)
    default_get_gateway_vco_routes = alicloud.vpn.get_gateway_vco_routes_output(vpn_connection_id=default_transit_router_vpn_attachment.vpn_id)
    pulumi.export("vpnGatewayVcoRouteId1", ids["routes"][0]["id"])
    ```


    :param Sequence[str] ids: A list of Vco Route IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str route_entry_type: The Routing input type. Valid values: `custom`, `bgp`.
    :param str status: The status of the vpn route entry. Valid values: `normal`, `published`.
    :param str vpn_connection_id: The id of the vpn connection.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['routeEntryType'] = route_entry_type
    __args__['status'] = status
    __args__['vpnConnectionId'] = vpn_connection_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:vpn/getGatewayVcoRoutes:getGatewayVcoRoutes', __args__, opts=opts, typ=GetGatewayVcoRoutesResult).value

    return AwaitableGetGatewayVcoRoutesResult(
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        page_number=pulumi.get(__ret__, 'page_number'),
        page_size=pulumi.get(__ret__, 'page_size'),
        route_entry_type=pulumi.get(__ret__, 'route_entry_type'),
        routes=pulumi.get(__ret__, 'routes'),
        status=pulumi.get(__ret__, 'status'),
        vpn_connection_id=pulumi.get(__ret__, 'vpn_connection_id'))
def get_gateway_vco_routes_output(ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                  output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                  page_number: Optional[pulumi.Input[Optional[int]]] = None,
                                  page_size: Optional[pulumi.Input[Optional[int]]] = None,
                                  route_entry_type: Optional[pulumi.Input[Optional[str]]] = None,
                                  status: Optional[pulumi.Input[Optional[str]]] = None,
                                  vpn_connection_id: Optional[pulumi.Input[str]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetGatewayVcoRoutesResult]:
    """
    This data source provides the Vpn Gateway Vco Routes of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.183.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default_instance = alicloud.cen.Instance("default", cen_instance_name=name)
    default_transit_router = alicloud.cen.TransitRouter("default",
        cen_id=default_instance.id,
        transit_router_description="desd",
        transit_router_name=name)
    default = alicloud.cen.get_transit_router_available_resources()
    default_customer_gateway = alicloud.vpn.CustomerGateway("default",
        name=name,
        ip_address="42.104.22.210",
        asn="45014",
        description="testAccVpnConnectionDesc")
    default_gateway_vpn_attachment = alicloud.vpn.GatewayVpnAttachment("default",
        customer_gateway_id=default_customer_gateway.id,
        network_type="public",
        local_subnet="0.0.0.0/0",
        remote_subnet="0.0.0.0/0",
        effect_immediately=False,
        ike_config={
            "ike_auth_alg": "md5",
            "ike_enc_alg": "des",
            "ike_version": "ikev2",
            "ike_mode": "main",
            "ike_lifetime": 86400,
            "psk": "tf-testvpn2",
            "ike_pfs": "group1",
            "remote_id": "testbob2",
            "local_id": "testalice2",
        },
        ipsec_config={
            "ipsec_pfs": "group5",
            "ipsec_enc_alg": "des",
            "ipsec_auth_alg": "md5",
            "ipsec_lifetime": 86400,
        },
        bgp_config={
            "enable": True,
            "local_asn": 45014,
            "tunnel_cidr": "169.254.11.0/30",
            "local_bgp_ip": "169.254.11.1",
        },
        health_check_config={
            "enable": True,
            "sip": "192.168.1.1",
            "dip": "10.0.0.1",
            "interval": 10,
            "retry": 10,
            "policy": "revoke_route",
        },
        enable_dpd=True,
        enable_nat_traversal=True,
        vpn_attachment_name=name)
    default_transit_router_vpn_attachment = alicloud.cen.TransitRouterVpnAttachment("default",
        auto_publish_route_enabled=False,
        transit_router_attachment_description=name,
        transit_router_attachment_name=name,
        cen_id=default_transit_router.cen_id,
        transit_router_id=default_transit_router.transit_router_id,
        vpn_id=default_gateway_vpn_attachment.id,
        zones=[{
            "zone_id": default.resources[0].master_zones[0],
        }])
    default_gateway_vco_route = alicloud.vpn.GatewayVcoRoute("default",
        route_dest="192.168.12.0/24",
        next_hop=default_transit_router_vpn_attachment.vpn_id,
        vpn_connection_id=default_transit_router_vpn_attachment.vpn_id,
        weight=100)
    default_get_gateway_vco_routes = alicloud.vpn.get_gateway_vco_routes_output(vpn_connection_id=default_transit_router_vpn_attachment.vpn_id)
    pulumi.export("vpnGatewayVcoRouteId1", ids["routes"][0]["id"])
    ```


    :param Sequence[str] ids: A list of Vco Route IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str route_entry_type: The Routing input type. Valid values: `custom`, `bgp`.
    :param str status: The status of the vpn route entry. Valid values: `normal`, `published`.
    :param str vpn_connection_id: The id of the vpn connection.
    """
    __args__ = dict()
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['pageNumber'] = page_number
    __args__['pageSize'] = page_size
    __args__['routeEntryType'] = route_entry_type
    __args__['status'] = status
    __args__['vpnConnectionId'] = vpn_connection_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:vpn/getGatewayVcoRoutes:getGatewayVcoRoutes', __args__, opts=opts, typ=GetGatewayVcoRoutesResult)
    return __ret__.apply(lambda __response__: GetGatewayVcoRoutesResult(
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        page_number=pulumi.get(__response__, 'page_number'),
        page_size=pulumi.get(__response__, 'page_size'),
        route_entry_type=pulumi.get(__response__, 'route_entry_type'),
        routes=pulumi.get(__response__, 'routes'),
        status=pulumi.get(__response__, 'status'),
        vpn_connection_id=pulumi.get(__response__, 'vpn_connection_id')))
